@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
@@ -51,47 +51,52 @@ enum
 
 
 
-static void     thunar_chooser_dialog_dispose             (GObject                  *object);
-static void     thunar_chooser_dialog_get_property        (GObject                  *object,
-                                                           guint                     prop_id,
-                                                           GValue                   *value,
-                                                           GParamSpec               *pspec);
-static void     thunar_chooser_dialog_set_property        (GObject                  *object,
-                                                           guint                     prop_id,
-                                                           const GValue             *value,
-                                                           GParamSpec               *pspec);
-static void     thunar_chooser_dialog_realize             (GtkWidget                *widget);
-static void     thunar_chooser_dialog_response            (GtkDialog                *widget,
-                                                           gint                      response);
-static gboolean thunar_chooser_dialog_selection_func      (GtkTreeSelection         *selection,
-                                                           GtkTreeModel             *model,
-                                                           GtkTreePath              *path,
-                                                           gboolean                  path_currently_selected,
-                                                           gpointer                  user_data);
-static gboolean thunar_chooser_dialog_context_menu        (ThunarChooserDialog      *dialog,
-                                                           guint                     button,
-                                                           guint32                   time);
-static void     thunar_chooser_dialog_update_accept       (ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_update_header       (ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_action_remove       (ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_browse_clicked      (GtkWidget                *button,
-                                                           ThunarChooserDialog      *dialog);
-static gboolean thunar_chooser_dialog_button_press_event  (GtkWidget                *tree_view,
-                                                           GdkEventButton           *event,
-                                                           ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_notify_expanded     (GtkExpander              *expander,
-                                                           GParamSpec               *pspec,
-                                                           ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_expand              (ThunarChooserDialog      *dialog);
-static gboolean thunar_chooser_dialog_popup_menu          (GtkWidget                *tree_view,
-                                                           ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_row_activated       (GtkTreeView              *treeview,
-                                                           GtkTreePath              *path,
-                                                           GtkTreeViewColumn        *column,
-                                                           ThunarChooserDialog      *dialog);
-static void     thunar_chooser_dialog_selection_changed   (GtkTreeSelection         *selection,
-                                                           ThunarChooserDialog      *dialog);
-
+static void        thunar_chooser_dialog_dispose             (GObject                  *object);
+static void        thunar_chooser_dialog_get_property        (GObject                  *object,
+                                                              guint                     prop_id,
+                                                              GValue                   *value,
+                                                              GParamSpec               *pspec);
+static void        thunar_chooser_dialog_set_property        (GObject                  *object,
+                                                              guint                     prop_id,
+                                                              const GValue             *value,
+                                                              GParamSpec               *pspec);
+static void        thunar_chooser_dialog_realize             (GtkWidget                *widget);
+static void        thunar_chooser_dialog_response            (GtkDialog                *widget,
+                                                              gint                      response);
+static gboolean    thunar_chooser_dialog_selection_func      (GtkTreeSelection         *selection,
+                                                              GtkTreeModel             *model,
+                                                              GtkTreePath              *path,
+                                                              gboolean                  path_currently_selected,
+                                                              gpointer                  user_data);
+static gboolean    thunar_chooser_dialog_context_menu        (ThunarChooserDialog      *dialog,
+                                                              guint                     button,
+                                                              guint32                   time);
+static void        thunar_chooser_dialog_update_accept       (ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_update_header       (ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_action_remove       (ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_browse_clicked      (GtkWidget                *button,
+                                                              ThunarChooserDialog      *dialog);
+static gboolean    thunar_chooser_dialog_button_press_event  (GtkWidget                *tree_view,
+                                                              GdkEventButton           *event,
+                                                              ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_notify_expanded     (GtkExpander              *expander,
+                                                              GParamSpec               *pspec,
+                                                              ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_expand              (ThunarChooserDialog      *dialog);
+static gboolean    thunar_chooser_dialog_popup_menu          (GtkWidget                *tree_view,
+                                                              ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_row_activated       (GtkTreeView              *treeview,
+                                                              GtkTreePath              *path,
+                                                              GtkTreeViewColumn        *column,
+                                                              ThunarChooserDialog      *dialog);
+static void        thunar_chooser_dialog_selection_changed   (GtkTreeSelection         *selection,
+                                                              ThunarChooserDialog      *dialog);
+static ThunarFile *thunar_chooser_dialog_get_file            (ThunarChooserDialog *dialog);
+static void        thunar_chooser_dialog_set_file            (ThunarChooserDialog *dialog,
+                                                              ThunarFile          *file);
+static gboolean    thunar_chooser_dialog_get_open            (ThunarChooserDialog *dialog);
+static void        thunar_chooser_dialog_set_open            (ThunarChooserDialog *dialog,
+                                                              gboolean             open);
 
 
 struct _ThunarChooserDialogClass
@@ -179,9 +184,7 @@ thunar_chooser_dialog_init (ThunarChooserDialog *dialog)
   GtkWidget         *swin;
 
   /* setup basic window properties */
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
   gtk_window_set_title (GTK_WINDOW (dialog), _("Open With"));
 
   /* create the main widget box */
@@ -239,10 +242,8 @@ thunar_chooser_dialog_init (ThunarChooserDialog *dialog)
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
   gtk_tree_view_column_set_attributes (column, renderer,
                                        "style", THUNAR_CHOOSER_MODEL_COLUMN_STYLE,
-                                       "style-set", THUNAR_CHOOSER_MODEL_COLUMN_STYLE_SET,
                                        "text", THUNAR_CHOOSER_MODEL_COLUMN_NAME,
                                        "weight", THUNAR_CHOOSER_MODEL_COLUMN_WEIGHT,
-                                       "weight-set", THUNAR_CHOOSER_MODEL_COLUMN_WEIGHT_SET,
                                        NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->tree_view), column);
 
@@ -391,7 +392,7 @@ thunar_chooser_dialog_response (GtkDialog *widget,
   GtkTreeIter          iter;
   const gchar         *content_type;
   const gchar         *exec;
-  GAppInfo            *app_info;
+  GAppInfo            *app_info = NULL;
   gboolean             succeed = TRUE;
   GError              *error = NULL;
   gchar               *path;
@@ -479,6 +480,7 @@ thunar_chooser_dialog_response (GtkDialog *widget,
       /* create launch context */
       context = gdk_app_launch_context_new ();
       gdk_app_launch_context_set_screen (context, gtk_widget_get_screen (GTK_WIDGET (dialog)));
+      gdk_app_launch_context_set_timestamp (context, gtk_get_current_event_time ());
 
       /* create fake file list */
       list.data = thunar_file_get_file (dialog->file); list.next = list.prev = NULL;
@@ -568,7 +570,6 @@ thunar_chooser_dialog_context_menu (ThunarChooserDialog *dialog,
 
   image = gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-  gtk_widget_show (image);
 
   /* run the menu on the dialog's screen (takes over the floating of menu) */
   thunar_gtk_menu_run (GTK_MENU (menu), GTK_WIDGET (dialog), NULL, NULL, button, timestamp);
@@ -626,7 +627,7 @@ thunar_chooser_dialog_update_header (ThunarChooserDialog *dialog)
   gchar       *text;
 
   _thunar_return_if_fail (THUNAR_IS_CHOOSER_DIALOG (dialog));
-  _thunar_return_if_fail (GTK_WIDGET_REALIZED (dialog));
+  _thunar_return_if_fail (gtk_widget_get_realized (GTK_WIDGET (dialog)));
 
   /* check if we have a valid file set */
   if (G_UNLIKELY (dialog->file == NULL))
@@ -942,11 +943,11 @@ thunar_chooser_dialog_expand (ThunarChooserDialog *dialog)
     }
 
   /* reset the cursor */
-  if (G_LIKELY (GTK_WIDGET_REALIZED (dialog)))
+  if (G_LIKELY (gtk_widget_get_realized (GTK_WIDGET (dialog))))
     gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
 
   /* grab focus to the tree view widget */
-  if (G_LIKELY (GTK_WIDGET_REALIZED (dialog->tree_view)))
+  if (G_LIKELY (gtk_widget_get_realized (dialog->tree_view)))
     gtk_widget_grab_focus (dialog->tree_view);
 }
 
@@ -1044,21 +1045,6 @@ thunar_chooser_dialog_selection_changed (GtkTreeSelection    *selection,
 
 
 
-/**
- * thunar_chooser_dialog_new:
- *
- * Allocates a new #ThunarChooserDialog.
- *
- * Return value: the newly allocated #ThunarChooserDialog.
- **/
-GtkWidget*
-thunar_chooser_dialog_new (void)
-{
-  return g_object_new (THUNAR_TYPE_CHOOSER_DIALOG, NULL);
-}
-
-
-
 /**
  * thunar_chooser_dialog_get_file:
  * @dialog : a #ThunarChooserDialog.
@@ -1068,7 +1054,7 @@ thunar_chooser_dialog_new (void)
  *
  * Return value: the #ThunarFile associated with @dialog.
  **/
-ThunarFile*
+static ThunarFile*
 thunar_chooser_dialog_get_file (ThunarChooserDialog *dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_CHOOSER_DIALOG (dialog), NULL);
@@ -1084,7 +1070,7 @@ thunar_chooser_dialog_get_file (ThunarChooserDialog *dialog)
  *
  * Associates @dialog with @file.
  **/
-void
+static void
 thunar_chooser_dialog_set_file (ThunarChooserDialog *dialog,
                                 ThunarFile          *file)
 {
@@ -1128,7 +1114,7 @@ thunar_chooser_dialog_set_file (ThunarChooserDialog *dialog,
     }
 
   /* update the header */
-  if (GTK_WIDGET_REALIZED (dialog))
+  if (gtk_widget_get_realized (GTK_WIDGET (dialog)))
     thunar_chooser_dialog_update_header (dialog);
 
   /* notify listeners */
@@ -1145,7 +1131,7 @@ thunar_chooser_dialog_set_file (ThunarChooserDialog *dialog,
  *
  * Return value: %TRUE if @dialog should open the file.
  **/
-gboolean
+static gboolean
 thunar_chooser_dialog_get_open (ThunarChooserDialog *dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_CHOOSER_DIALOG (dialog), FALSE);
@@ -1161,7 +1147,7 @@ thunar_chooser_dialog_get_open (ThunarChooserDialog *dialog)
  *
  * Sets whether the chooser @dialog should open the file.
  **/
-void
+static void
 thunar_chooser_dialog_set_open (ThunarChooserDialog *dialog,
                                 gboolean             open)
 {
@@ -1234,7 +1220,7 @@ thunar_show_chooser_dialog (gpointer    parent,
                          NULL);
 
   /* check if we have a toplevel window */
-  if (G_LIKELY (window != NULL && GTK_WIDGET_TOPLEVEL (window)))
+  if (G_LIKELY (window != NULL && gtk_widget_get_toplevel (window)))
     {
       /* dialog is transient for toplevel window and modal */
       gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
